import _ from 'lodash';
import { THIRD_PARTY_PROXY_TYPES } from '../constants.js';
import { ClashClient } from '../http.js';
import { InfluxClient } from '../influx.js';
import { logger } from '../logger.js';
import { testDelay } from '../utils/proxy.js';
export default async function ({ config, cwd, }) {
    const clashClient = ClashClient.createClient(config.clash);
    const influxClient = InfluxClient.createClient(config.influx);
    const { proxies } = await clashClient.getProxies();
    const thirdPartyProxyNames = Object.keys(proxies).filter((proxy) => THIRD_PARTY_PROXY_TYPES.includes(proxies[proxy].type));
    const thirdPartyProxies = _.chain(thirdPartyProxyNames)
        .uniq()
        .map((name) => proxies[name])
        .value();
    logger.info(`Testing ${thirdPartyProxyNames.length} proxies...`);
    for (const proxy of thirdPartyProxies) {
        logger.info(`Testing delay for ${proxy.name}...`);
        try {
            const { min, max, avg } = await testDelay(clashClient, proxy.name);
            logger.info(`Delay for ${proxy.name}: min ${min}ms, max ${max}ms, avg ${avg}ms`);
            await influxClient.recordDelay(proxy.name, { min, max, avg });
        }
        catch (error) {
            if (error instanceof Error) {
                logger.error(`Delay test failed for ${proxy.name}: ${error.message}`);
                await influxClient.recordDelay(proxy.name, {
                    min: 0,
                    max: 0,
                    avg: 0,
                });
            }
        }
    }
    logger.info('Done.');
    await influxClient.close();
}
//# sourceMappingURL=start.js.map