import * as fs from 'node:fs/promises';
import { join } from 'node:path';
import yaml from 'yaml';
import zod from 'zod';
import { CONFIG_FILE } from './constants.js';
const Config = zod.object({
    clash: zod.object({
        host: zod.string(),
        port: zod.number(),
        secret: zod.string(),
        ssl: zod.boolean().optional().default(false),
    }),
    influx: zod.object({
        url: zod.string(),
        org: zod.string(),
        token: zod.string(),
        bucket: zod.string(),
    }),
});
export const loadConfig = async (cwd) => {
    const file = join(cwd, CONFIG_FILE);
    const config = yaml.parse(await fs.readFile(file, 'utf8'));
    return await Config.parseAsync(config);
};
//# sourceMappingURL=config.js.map